@@ -66,7 +66,9 @@ impl State {
             }
         }
 
-        let resize = image::imageops::resize(&buffer, 256 * (x/y), 256 * (y/x), image::imageops::FilterType::Nearest);
+        let x_resize: u32 = ( 256.0 * (x as f32 / y as f32) ).floor() as u32;
+        let y_resize: u32 = ( 256.0 * (y as f32 / x as f32) ).floor() as u32;
+        let resize = image::imageops::resize(&buffer, x_resize, y_resize, image::imageops::FilterType::Nearest);
 
         resize.save(name).unwrap();
     }
